aboutsummaryrefslogtreecommitdiffhomepage
path: root/patches/api/0457-Fix-SpawnerEntry-Equipment-API.patch
blob: 0a16b34cd5e0d30b3d439ae7eb86cd1551a87042 (plain)
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
From 0000000000000000000000000000000000000000 Mon Sep 17 00:00:00 2001
From: Jake Potrebic <jake.m.potrebic@gmail.com>
Date: Fri, 26 Apr 2024 17:00:00 -0700
Subject: [PATCH] Fix SpawnerEntry$Equipment API


diff --git a/src/main/java/org/bukkit/block/spawner/SpawnerEntry.java b/src/main/java/org/bukkit/block/spawner/SpawnerEntry.java
index 02b3471774ff1fd4ad15c2f04064fd485ef8f3e5..0fc5f04b8bb475e8afce61c6187a390cd36c3d9f 100644
--- a/src/main/java/org/bukkit/block/spawner/SpawnerEntry.java
+++ b/src/main/java/org/bukkit/block/spawner/SpawnerEntry.java
@@ -121,28 +121,29 @@ public class SpawnerEntry {
         private final Map<EquipmentSlot, Float> dropChances;
 
         public Equipment(@NotNull LootTable equipmentLootTable, @NotNull Map<EquipmentSlot, Float> dropChances) {
+            Preconditions.checkArgument(equipmentLootTable != null, "table cannot be null"); // Paper
             this.equipmentLootTable = equipmentLootTable;
             this.dropChances = dropChances;
         }
 
         /**
          * Set the loot table for the entity.
          * <br>
-         * To remove a loot table use null. Do not use {@link LootTables#EMPTY}
-         * to clear a LootTable.
+         * To remove a loot table use {@link LootTables#EMPTY}.
          *
          * @param table this {@link org.bukkit.entity.Mob} will have.
          */
         public void setEquipmentLootTable(@NotNull LootTable table) {
+            Preconditions.checkArgument(table != null, "table cannot be null"); // Paper
             this.equipmentLootTable = table;
         }
 
         /**
          * Gets the loot table for the entity.
          * <br>
          *
-         * If an entity does not have a loot table, this will return null, NOT
-         * an empty loot table.
+         * If an entity does not have a loot table, this will return an
+         * empty loot table.
          *
          * @return the loot table for this entity.
          */
@@ -121,28 +121,29 @@ public class SpawnerEntry {
 
         /**
-         * Set the loot table for the entity.
+         * Set the loot table for the spawned entity's equipment slots.
          * <br>
@@ -121,28 +121,29 @@ public class SpawnerEntry {
 
         /**
-         * Gets the loot table for the entity.
+         * Gets the loot table for the spawned entity's equipment.
          * <br>
          *